@@ -3,7 +3,8 @@
 # update-oui-database.sh
 # This script creates the src/oui.h file needed by netdiscover.
 #
-# Copyright 2016-2022 Joao Eriberto Mota Filho <eriberto@debian.org>
+# Copyright 2016-2025 Joao Eriberto Mota Filho <eriberto@debian.org>
+# Copyright 2025      Bernhard M. Wiedemann <bwiedemann+git@suse.de>
 # This file is under GPL-2+ license.
 #
 # netdiscover was written by Jaime Penalba Estebanez <jpenalbae@gmail.com>
@@ -25,14 +26,21 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-VERSION=0.5
+VERSION=0.6
 
 # CHANGELOG
 #
+# v0.6, 2025-08-14, Eriberto
+#
+# * Using mtime to define DATA2 to make update-oui-database.sh reproducible.
+#   Thanks to Bernhard M. Wiedemann <bwiedemann+git@suse.de>. (PR #38)
+# * Added an autofix for x01 binary byte.
+# * Added a check for dos2unix results.
+#
 # v0.5, 2022-10-29, Eriberto
 #
-# Change main download site from https://linuxnet.ca/ieee/oui.txt (link down)
-# to https://standards-oui.ieee.org. (Fix #23)
+# * Change main download site from https://linuxnet.ca/ieee/oui.txt (link down)
+#   to https://standards-oui.ieee.org. (Fix #23)
 #
 # v0.4, 2022-02-17, Eriberto
 #
@@ -59,9 +67,9 @@ VERSION=0.5
 #####################
 
 DATE=$(date +%F | tr -d "-")
-DATE2=$(date +%F)
 NAME=oui.txt-$DATE
 OUIFILE=src/oui.h
+[ -e $NAME ] && DATE2=$(date -r $NAME +%F) || DATE2=$(date +%F)
 
 # Minimum amount of MAC addresses for check. Is not needed to update this every
 # time. The main goal is check if a generated file was corrupted.
@@ -124,6 +132,12 @@ fi
 
 gzip -V > /dev/null 2> /dev/null || { printf "\nYou need gzip command to use this script.\n\n"; exit 1; }
 
+#################
+# Check for sed #
+#################
+
+sed --version > /dev/null 2> /dev/null || { printf "\nYou need sed command to use this script.\n\n"; exit 1; }
+
 ####################
 # OUI.txt download #
 ####################
@@ -163,7 +177,9 @@ then
     $DOWN $URL
 fi
 
-# Unzip if needed
+###################
+# Unzip if needed #
+###################
 
 if [ -f "${NAME}.gz" ]
 then
@@ -171,6 +187,17 @@ then
     gunzip "${NAME}.gz"
 fi
 
+#######################
+# Fixing known issues #
+#######################
+
+# Removing binary x01
+grep -qaP '\x01' $NAME && sed 's/\x01/ /g' $NAME > oui.x01 && mv oui.x01 $NAME
+
+######################
+# Processing OUI.txt #
+######################
+
 # Final check and conversion to Unix
 
 TOTAL_MAC=$(cat $NAME | grep "base 16" | wc -l)
@@ -183,6 +210,13 @@ fi
 
 dos2unix -q $NAME
 
+# Check the conversion to Unix
+
+egrep $'\r' $NAME > /dev/null && { printf "\n\nERROR: dos2unix failed to convert the file $NAME"; \
+                                   printf "\n\nRunning dos2unix without -q option to identify the problem:\n\n"; \
+                                   dos2unix $NAME; \
+                                   exit 1; }
+
 ######################
 # Building src/oui.h #
 ######################
